@@ -381,3 +381,14 @@ bool Award::isConfirmed(const QString &refName){
 		}
 	return false;
 }
+
+bool Award::isValidReference(const QString &refName){
+// To know if a reference is a valid one or not.
+//cout << "Award::isValidReference:  " << refName << endl;
+	References::iterator it;
+	for ( it = references.begin(); it != references.end(); ++it ){
+		 if (((*it).getReference()+"-"+(*it).getLongName()) == refName)
+			return true;
+		}
+	return false;
+}
