@@ -33,6 +33,7 @@
 #include <qaction.h>
 #include <qapplication.h>
 #include <qwidget.h>
+//#include <qthread.h>
 #include <klineedit.h>
 #include <kcombobox.h>
 #include "klogui.h"
@@ -93,6 +94,8 @@
 #include "awards.h"
 #include "award.h"
 #include "reference.h"
+//#include "klogtip.h"
+
 //#include <Qt3Support>
 //#include "ostream.h"
 
@@ -105,10 +108,12 @@
 //const char SEPARATOR = ',';
 
 /** Klog is the base class of the project */
-
-class Klog : public klogui {
+class Klog : public klogui{
+//class Klog : public klogui, QThread {
 //f  friend class QslNeeded;
 	friend class dxClusterSpotItem;
+	friend class bandMapSpotItem;
+
 	Q_OBJECT
 	public:
 	/** construtor */
@@ -124,10 +129,13 @@ class Klog : public klogui {
 
 	LogBook logbook;
 	LogBook oLogbook; //Ordered logbook (by date) (exit from orderLog)
+	LogBook templogbook; //The "not yet saved" logbook.
 
 	//public:
 	bool haveWorld();
 
+//	virtual void run();
+
 	public slots:
 	void slotUpdateTime();
 	void slotQSLRec();
@@ -144,16 +152,17 @@ class Klog : public klogui {
 	void slotQslSentBoxChanged();
 	void slotQslRecvBoxChanged();
 	void slotQSLcomboBoxChanged();
-	void slotLocalAwardChanged();
 	void slotSearchQSO2QSL(); // Shows in the search box QSO from which we need the QSL and we have not sent it.
 	void slotPreferences();
 	void fileNew();
 	void fileSave();
 	void fileSaveAs();
 	void filePrint();
+	//void printLabels(); // Generate the file for GLabels or KBarcode
 	void slothamlibUpdateFrequency();
 
-	void adifFileSave();
+//	void adifFileSave();
+	void adifTempFileSave(const QString& fn, LogBook lb, bool manualSave);  // To save the templog automatically after each QSO is added
 	//  void adifSaveAs(const QString& tfileName);
 	void adifReadLog(const QString& tfileName);
 	int getProgresStepForDialog(int totalSteps);
@@ -179,7 +188,6 @@ class Klog : public klogui {
 //  void doPaint(QPainter *p, int autofit, int w, int h);
 
 
-  
 
   Qso getByCall(const QString& tqrz);
   Qso getByNumber(const int n);
@@ -190,8 +198,8 @@ class Klog : public klogui {
   private slots:
 	void slotLocatorChanged();
 	void slotMyLocatorChanged();
-    void slotClusterCloseConnection();
-    void slotClusterSendToServer();
+	void slotClusterCloseConnection();
+	void slotClusterSendToServer();
     void slotClusterSocketReadyRead();
     void slotClusterSocketConnected();
     void slotClusterSocketConnectionClosed();
@@ -209,33 +217,38 @@ class Klog : public klogui {
 
   private:
 
-    Qso qso;
-    Qso previousQso;       // This and workedCall is to check if a call has been previously
-    WorkedCalls workedCall;// worked and it is posible to reuse the data.
-    bool completeWithPrevious;	// Configuration parameter
+	Qso qso;
+	Qso previousQso;       // This and workedCall is to check if a call has been previously
+	WorkedCalls workedCall;// worked and it is posible to reuse the data.
+	bool completeWithPrevious;	// Configuration parameter
+	bool requireMandatory;		// Configuration parameter (requires all the mandatory data for all the QSO) (QRZ, date, time, band, mode, RST (TX&RX))
+	QString tempLogFile;	// Temp log to save automatically
 
-    typedef QValueList<Reference> References; // The list of references of the current award.
-    References references;		// The references of the current award.
+	typedef QValueList<Reference> References; // The list of references of the current award.
+	References references;		// The references of the current award.
 
-    // Awards supported by KLog
-    Adif adif;
-    AwardDXCC dxcc;
-    AwardWAZ waz;
-    Awards awards;
-    Award award;
-    QStringList awardReferences;	// All the references of the current award to prepare the combobox
+
+	// Awards supported by KLog
+	Adif adif;
+	AwardDXCC dxcc;
+	AwardWAZ waz;
+	Awards awards;
+	Award award;
+	QStringList awardReferences;	// All the references of the current award to prepare the combobox
 	QString DXClusterServerToUse;
+	void processLogLine (const QString& tLogLine); // Process a line of data/qso from adifReadLog
 	void clearGUI();
-    bool didISave();
-    bool haveAllTheFields();
-    void entityState(const int tentity);
-    void addQSOToLog();
-    void readConf();
-    void slotImportTlf();
-    void slotAddLog();
+	bool didISave();
+	bool haveAllTheFields();
+	void entityState(const int tentity);
+	void addQSOToLog();
+	void readConf();
+	void slotImportTlf();
+	void slotAddLog();
 	void slotIOTAChanged();
 	void prepareIOTAComboBox (const int tenti);
 	void prepareAwardBox (const int tenti);
+	void readAwardsStatus();	//Reads the full DXCC&WAZ status
 	bool checkIfValidDXCluster(const QString &tdxcluster); // Is a valid URL? 
 //    void slotQslNeededCheck();
 	void setMyQrz(const QString &tqrz);
@@ -244,66 +257,80 @@ class Klog : public klogui {
 	QString getMyLocator() const;
 	void showWhere(const int enti);
 	QString getThisQSODXLocator ();
-    int needToWorkFromCluster(const QString &tqrz, const int tband); // 0 confirmed, 1 worked, 2 new one, -1 error
+	int needToWorkFromCluster(const QString &tqrz, const int tband); // 0 confirmed, 1 worked, 2 new one, -1 error
 //    QColor stateColor(const QString &tqrz, const int tband);    
     void showAwardsNumbers(); // Shows how many worked, confirmed, ...
     void clearAwards();
     void showDistancesAndBeam(const int dist, const int beam); // Shows distance and beam
-    void completeAllQSOsFromLog();
-    void KloggetAllTheCallsFromLog(); // To be run once after the log is read from the disk.
-    void fillEntityBandState(const int enti);
-    void sortLog(); //To order by date the log and produce OLog
-    void showIfPreviouslyWorked(); // Uses previousQso and workedCall
-    void addToPreviouslyWorked(); // Uses previousQso and workedCall    
-    void completeThePreviouslyWorked();
-    void getAllTheCallsFromLog();
-    QString getNumberString(const int intNumber);
-    int getEntityFromCall(); // Just read the call from the QRZ box and returns the entity number
 
-    void prepareAwardComboBox(const int tenti);
-    QString checkExtension(QString extension); // To check the extension of the file // TNX Kike
+// Worked before
+	void completeAllQSOsFromLog();
+	//void KloggetAllTheCallsFromLog(); // To be run once after the log is read from the disk.
+	void fillEntityBandState(const int enti);
+	void sortLog(); //To order by date the log and produce OLog
+	void showIfPreviouslyWorked(); // Uses previousQso and workedCall
+	void addToPreviouslyWorked(); // Uses previousQso and workedCall    
+	void completeThePreviouslyWorked();
+	void getAllTheCallsFromLog();// To be run once after the log is read from the disk.
+	
+	QString getNumberString(const int intNumber); //Receivs a number a returns a string of a fixed length
+	int getEntityFromCall(); // Just read the call from the QRZ box and returns the entity number
 
-    void listHamlib();
+	void prepareAwardComboBox(const int tenti);
+	QString checkExtension(QString extension); // To check the extension of the file // TNX Kike
 
+	void listHamlib();
+	void addDXSpotToBandMap(QString& freq, QString& dx, QString& from, QColor& dxcolor); // Adds a DXSpot to the bandmap from dxcluster
+	void showTip();
+	QString returnLines(const QString& tword); //Puts \n where \\n
 
 //    int band2Num(const QString &tband);
 
   //  Qso qso;
 	bool showProgressDialog;
+	bool qslViac;
 	QColor ledColor;
 	Locator locator;
 	QString myLocatorTemp;  // To manage temp locators and distances
-    QString dxLocator;
-    QString myQrz;
-    QString myLocator;
-    QString klogDir;
+	QString dxLocator;
+	QString myQrz;
+	QString myLocator;
+	QString klogDir;
 	QString logFileNameToOpen;
 	QString logFileNameToSave;
-    QString aux;
+	QString aux;
     QString operatorStringAux;
     QString textStringAux;
     QString KLogVersion;
+	QString dateString;
+	QString timeString;
+	QString datesString;
+	QString daterString;
+	QString qsoLine;
+	QString adifTab;
+	QString theData;
+ 
 
     KPrinter printer;
 //    QPainter p;
-    
-    QColorGroup colorGroup; // For cluster
+
+QColorGroup colorGroup; // For cluster
     QPainter clusterPainter; // For cluster
-    QColor confirmedColor;
-    QColor workedColor;
-    QColor neededColor;
-    QColor defaultColor;
-    QColor dxSpotColor;
-    QColor blackColor;    
-    QColor colorInUse;  // Till now only in use in Klog::slotSearchButton()
-    int number;  // QSO number
-    int confirmed; //confirmed QSOs
-    int rstrx;  // RST received from the other peer
-    int rsttx;  // RST you pass to the other peer
-    int tTxValue;
-    int tRxValue;
-    int sTxValue;
-    int sRxValue;
+QColor confirmedColor;
+QColor workedColor;
+QColor neededColor;
+QColor defaultColor;
+QColor dxSpotColor;
+QColor blackColor;
+QColor colorInUse;  // Till now only in use in Klog::slotSearchButton()
+int number;  // QSO number
+int confirmed; //confirmed QSOs
+int rstrx;  // RST received from the other peer
+int rsttx;  // RST you pass to the other peer
+int tTxValue;
+int tRxValue;
+int sTxValue;
+int sRxValue;
 
 
 	int band;   // Band used in the QSO
@@ -311,7 +338,7 @@ class Klog : public klogui {
 	QString power;  // Power used for the QSO (in your side)
 	QStringList fields; // Auxiliary variable to splir log/formated strings
 	int i, j;
-	int kk;     // This is just for intra-fuction use 
+	int kk; // This is just for intra-fuction use 
 	int itemPos; // for modifying
 	int enti;   //Just for entity name show
 	int entiBak;
@@ -319,7 +346,7 @@ class Klog : public klogui {
 	int callLenPrev;  // The previous call's lenght to detect if deleting
 	int callLenFound;
 	int beam; // the beam in degrees DELETE
-	int distance;     // Distance between the two stations in the QSO
+	int distance; // Distance between the two stations in the QSO
 	bool lastDelete;  // Last key pressed is delete?
 	bool callFound;   // Boolean to show if the call has been found
 	bool modify;
@@ -331,110 +358,128 @@ class Klog : public klogui {
 	bool actionRec;
 	bool timeInUTC;   // Time in UTC or LocalTime
 	bool realTimeLog; // The clock will be in real time or stopped to add previous QSOs
-//    bool justOneTime; //  For slotQslRec to avoid twice confirmed--
-    bool wasConfirmed; // For the same purporse as above.
+//bool justOneTime; //  For slotQslRec to avoid twice confirmed--
+	bool wasConfirmed; // For the same purporse as above.
 	bool openLastByDefault;
-    QString mode;
-    QString qrz;      // Just used in the searching functions
-    QString iota;
-    QString localAward;	// A String as the iota to temporaly save the localAward (if any)
-    QDateTime dateTime;
-    QDateTime dateTimeContinuous;
-    QDate qslSen;
-    QDate qslRec;
-//    QDate date;
-//    QTime time;
-    QString comment;
-    QString dateTimeString;
-//    Preferences setupDialog;
+QString mode;
+QString qrz;  // Just used in the searching functions
+QString iota;
+QString localAward;	// A String as the iota to temporaly save the localAward (if any)
+QDateTime dateTime;
+QDateTime dateTimeContinuous;
+QDate qslSen;
+QDate qslRec;
+//QDate date;
+//QTime time;
+QString comment;
+QString dateTimeString;
+//Preferences setupDialog;
 
-    QPixmap *editdeletePixMap;
-    QPixmap *editdeleteOffPixMap;
-    QPixmap *qslRecPixMap;
-    QPixmap *qslRecOffPixMap;
-    QPixmap *qslSenPixMap;
-    QPixmap *qslSenOffPixMap;
-    // Cluster variables
-    int neededWorkedConfirmed; // 0 needed, 1 worked, 2 confirmed, 3 default
-    QSocket *socket;
-    QLineEdit *inputText;
-    QString dxClusterHost;
-    QString dxClusterString;
-    QString dxClusterDxCall;
-    QString dxClusterShow;
-//    QString dxClustertmp;
-    int dxClusterPort;
-    int dxClusterCallLen;
-    int dxClusterEnti;
-    int dxClusterBand; // tmp variable
-    bool dxClusterConnected;
-    bool dxClusterHFSpots;
-    bool dxClusterVHFSpots;
-    bool dxClusterWARCSpots;    
-    bool dxClusterWXANNounces;
-    bool dxClusterWCYANNounces;
-    bool dxClusterANNounces;
-    bool dxClusterConfirmedSpots;
-//    void paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int alignment );
+QPixmap *editdeletePixMap;
+QPixmap *editdeleteOffPixMap;
+QPixmap *qslRecPixMap;
+QPixmap *qslRecOffPixMap;
+QPixmap *qslSenPixMap;
+QPixmap *qslSenOffPixMap;
+// Cluster variables
+int neededWorkedConfirmed; // 0 needed, 1 worked, 2 confirmed, 3 default
+QSocket *socket;
+QLineEdit *inputText;
+QString dxClusterHost;
+QString dxClusterString;
+QString dxClusterDxCall;
+QString dxClusterShow;
+//QString dxClustertmp;
+int dxClusterPort;
+int dxClusterCallLen;
+int dxClusterEnti;
+int dxClusterBand; // tmp variable
+	bool dxClusterConnected;
+	bool dxClusterHFSpots;
+	bool dxClusterVHFSpots;
+	bool dxClusterWARCSpots;
+	bool dxClusterWXANNounces;
+	bool dxClusterWCYANNounces;
+	bool dxClusterANNounces;
+	bool dxClusterConfirmedSpots;
+//void paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int alignment );
 //  virtual void paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int align );
-    
-    KBugReport  *bugReport;
-    // 0 QRZ
-    // 1 Date
-    // 2 Time
-    // 3 Band
-    // 4 Mode
-    // 5 RST tx
-    // 6 RST rx
-    bool haveAllMandatoryFields[6];
 
-    // hamlib support
-    kloghamlib KlogHamlib;
-    bool hamlib;    
-    bool hamlibReading;
-    bool hamlibPossible;
-    double hamlibFreq;
-    int bauds;
-    int rignameNumber;
-    //int strength;
-    int hamlibInterval;
-    QString serialPort;
-    QTimer *hamlibtimer;
+KBugReport  *bugReport;
+// 0 QRZ
+// 1 Date
+// 2 Time
+// 3 Band
+// 4 Mode
+// 5 RST tx
+// 6 RST rx
+bool haveAllMandatoryFields[6];
+
+// hamlib support
+kloghamlib KlogHamlib;
+bool hamlib;
+bool hamlibReading;
+bool hamlibPossible;
+double hamlibFreq;
+int bauds;
+int rignameNumber;
+//int strength;
+int hamlibInterval;
+QString serialPort;
+QTimer *hamlibtimer;
+
 
-    
 };
 
 class dxClusterSpotItem : public KListViewItem {
 public:
-    dxClusterSpotItem( KListView *parent, const QString& spot, const QColor& color );
-    ~dxClusterSpotItem();
-    virtual void paintCell( QPainter *p, const QColorGroup &cg,
-                            int column, int width, int alignment );
+dxClusterSpotItem( KListView *parent, const QString& spot, const QColor& color );
+~dxClusterSpotItem();
+virtual void paintCell( QPainter *p, const QColorGroup &cg,
+int column, int width, int alignment );
 
-//    Message *message() { return myMessage; }
+//Message *message() { return myMessage; }
 
 protected:
   //  Message *myMessage;
-      QColor spotColor;
+  QColor spotColor;
 
 };
 
+
 class searchBoxItem : public KListViewItem {
 public:
-    searchBoxItem( KListView *parent, const QString& call, const QString& date, const QString& time, const QString& band, const QString& mode, const QString& RSTsent, const QString& RSTrec, const QString& numb, const QColor& color );
-    ~searchBoxItem();
-    virtual void paintCell( QPainter *p, const QColorGroup &cg,
-                            int column, int width, int alignment );
+searchBoxItem( KListView *parent, const QString& call, const QString& date, const QString& time, const QString& band, const QString& mode, const QString& RSTsent, const QString& RSTrec, const QString& numb, const QColor& color );
+~searchBoxItem();
+virtual void paintCell( QPainter *p, const QColorGroup &cg,
+        int column, int width, int alignment );
 
 
 protected:
-      QColor qsoColor;
-      QString call;
-      QString date;
-      QString band;
-      QString mode;
-      QString RSTsent;
-      QString RSTrec;
+  QColor qsoColor;
+  QString call;
+  QString date;
+  QString band;
+  QString mode;
+  QString RSTsent;
+  QString RSTrec;
 };
 
+// class bandMapSpotItem : public KListViewItem {
+// // Items for the BandMap
+// public:
+// bandMapSpotItem( KListView *parent, const QString& freq, const QString& dx, const QString& from, const QColor& dxcolor );
+// ~bandMapSpotItem();
+// virtual void paintCell( QPainter *p, const QColorGroup &cg,
+//                             int column, int width, int alignment );
+// 
+// //Message *message() { return myMessage; }
+// 
+// protected:
+//   //  Message *myMessage;
+// 	QColor spotColor;
+// 	
+// 
+// };
+
 #endif
