@@ -24,9 +24,7 @@ using namespace std;
 kloghamlib::kloghamlib(){
 	//cout << "KLogHamlib::constructor" << endl;
 	//t.start();
-    
-    //qDebug( "Time elapsed: %d ms", t.elapsed() );
-	
+	//qDebug( "Time elapsed: %d ms", t.elapsed() );
 	myrig_model =	-1;
 	rigLaunched = false;
 	bauds = 19200;
@@ -101,22 +99,15 @@ bool kloghamlib::init(){
 		if (retcode != RIG_OK) {
 			//cout << "KlogHamlib::init - 10.3" << endl;
 			rigLaunched = false;
-			//cout << "KlogHamlib::init - 10.4" << endl;
 			// TODO: To make some error visible with qmessages and so on
 			//printf("rig_open: error = %s\n", rigerror(retcode));
-			//cout << "KlogHamlib::init - 10.5" << endl;
 			return false;
 			//    exit(2);
 		}
-		//cout << "KlogHamlib::init - 10.6" << endl;
 		//printf("Port %s opened ok\n", serialPort);
-		//cout << "KlogHamlib::init - 10.7" << endl;
 		rigLaunched = true;
-		//cout << "KlogHamlib::init - 11" << endl;
 	}else{
-		//cout << "Rig is launched" << endl;
 	}
-		
 	return true;
 }
 
@@ -131,18 +122,6 @@ void kloghamlib::close(){
 double kloghamlib::getFrequency(){
 	//cout << "KLogHamlib::getFrequency" << endl;
 	if (!rigLaunched){
-	// cout << "getFrequency: !rigLaunched" << endl;
-		/* The folllowing was commented to save execution time avoiding to "init" once we check the freq.
-		if (init()){
-			if (rigLaunched){
-				rig_get_freq(radio, RIG_VFO_CURR, &freq);
-				return freq/1000; // We are getting the freq in KHz
-			}else{
-				return 0.0;
-			}
-		}else{
-			
-		}*/
 		return 0.0;
 	}else{
 		rig_get_freq(radio, RIG_VFO_CURR, &freq);
@@ -228,15 +207,7 @@ int kloghamlib::getStrength(){
 	//cout << "KLogHamlib::getStrength" << endl;
 	i = -1; // Aux variable
 	if (!rigLaunched){
-		if (init()){
-			if (rigLaunched){
-				retcode = rig_get_strength(radio, RIG_VFO_CURR, &strength);
-			}else{
-				return -1;
-			}//Closes the rigLaunched
-		}else{
-			return -1;
-		}//Closes the init
+		return -1;
 	}else{ //rigLaunched = true
 		retcode = rig_get_strength(radio, RIG_VFO_CURR, &strength);
 	}
@@ -274,87 +245,55 @@ int kloghamlib::getStrength(){
 void kloghamlib::setFrequency(double tFreq){
 //    cout << "kloghamlib - Frecuencia: " << QString::number(tFreq) << endl;
 	//cout << "KLogHamlib::setFrequency" << endl;
-    if (!rigLaunched){
-      if (init()){
-   if (rigLaunched){
-       retcode = rig_set_freq(radio, RIG_VFO_CURR, tFreq*1000);
-   }
-}
-  }else{retcode = rig_set_freq(radio, RIG_VFO_CURR, tFreq*1000);}
+	if (!rigLaunched){
+		return;
+	}else{
+		retcode = rig_set_freq(radio, RIG_VFO_CURR, tFreq*1000);
+	}
 }
 
 void kloghamlib::setMode (const QString& tMode){
 //	cout << "KLogHamlib::setMode" << endl;
 //cout << "Mode received: " << tMode << endl;
-    if (!rigLaunched){
-      if (init()){
-   if (rigLaunched){
- 
-      if (tMode == "AM"){
- retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_AM, RIG_PASSBAND_NORMAL);     
-  }else if (tMode == "CW"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_CW, RIG_PASSBAND_NORMAL);     
-  }else if (tMode == "CWR"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_CWR, RIG_PASSBAND_NORMAL);        
-  }else if (tMode == "USB"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_USB, RIG_PASSBAND_NORMAL);       
-  }else if (tMode == "LSB"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_LSB, RIG_PASSBAND_NORMAL);          
-  }else if (tMode == "RTTY"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_RTTY, RIG_PASSBAND_NORMAL);     
-  }else if (tMode == "RTTYR"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_RTTYR, RIG_PASSBAND_NORMAL);     
-  }else if (tMode == "FM"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_FM, RIG_PASSBAND_NORMAL);     
-  }else if (tMode == "WFM"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_WFM, RIG_PASSBAND_NORMAL);     
-}else{}
-   }
-}
-  }else{
-        if (tMode == "AM"){
- retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_AM, RIG_PASSBAND_NORMAL);     
-  }else if (tMode == "CW"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_CW, RIG_PASSBAND_NORMAL);     
-  }else if (tMode == "CWR"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_CWR, RIG_PASSBAND_NORMAL);        
-  }else if (tMode == "USB"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_USB, RIG_PASSBAND_NORMAL);       
-  }else if (tMode == "LSB"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_LSB, RIG_PASSBAND_NORMAL);          
-  }else if (tMode == "RTTY"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_RTTY, RIG_PASSBAND_NORMAL);     
-  }else if (tMode == "RTTYR"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_RTTYR, RIG_PASSBAND_NORMAL);     
-  }else if (tMode == "FM"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_FM, RIG_PASSBAND_NORMAL);     
-  }else if (tMode == "WFM"){
-   retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_WFM, RIG_PASSBAND_NORMAL);     
-}else{}
-
-  } 
+	if (!rigLaunched){
+		return;
+	}else{
+		if (tMode == "AM"){
+			retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_AM, RIG_PASSBAND_NORMAL);
+		}else if (tMode == "CW"){
+			retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_CW, RIG_PASSBAND_NORMAL);     
+		}else if (tMode == "CWR"){
+			retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_CWR, RIG_PASSBAND_NORMAL);        
+		}else if (tMode == "USB"){
+			retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_USB, RIG_PASSBAND_NORMAL);       
+		}else if (tMode == "LSB"){
+			retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_LSB, RIG_PASSBAND_NORMAL);          
+		}else if (tMode == "RTTY"){
+			retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_RTTY, RIG_PASSBAND_NORMAL);     
+		}else if (tMode == "RTTYR"){
+			retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_RTTYR, RIG_PASSBAND_NORMAL);     
+		}else if (tMode == "FM"){
+			retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_FM, RIG_PASSBAND_NORMAL);     
+		}else if (tMode == "WFM"){
+			retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_WFM, RIG_PASSBAND_NORMAL);     
+		}else{}
+	}
 }
 
 int kloghamlib::getPower(){
-    // To Be Done
+    //TODO: This is To Be Done
 	//cout << "KLogHamlib::getPower" << endl;
-   if (!rigLaunched){
-      if (init()){
-   if (rigLaunched){
-      // retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_USB, RIG_PASSBAND_NORMAL);
-       return 0;
-   }
-}
-  }else{
-  //    retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_USB, RIG_PASSBAND_NORMAL);
-      return 0;
-  }    
-      return 0;    
+	if (!rigLaunched){
+		return 0;
+	}else{
+		//    retcode = rig_set_mode(radio, RIG_VFO_CURR, RIG_MODE_USB, RIG_PASSBAND_NORMAL);
+		return 0;
+	}
 }
 
 void kloghamlib::getRigList(){
 	//cout << "KLogHamlib::getRigLilst" << endl;
-	rig_load_all_backends();   
+	rig_load_all_backends();
 }
 
 void kloghamlib::setBauds(int tbauds){
