@@ -46,7 +46,7 @@ public:
 
   void setQrz(const QString &tqrz);
   QString getQrz() const;
-  
+
 //  void setRrst(int trst);
 //  int getRrst() const;
 
@@ -63,7 +63,7 @@ public:
   QTime getTime() const;  
 
   void setRstrx(int trstrx);
-  int getRstrx() const;        
+  int getRstrx() const;
 
   void setRsttx(int trsttx);
   int getRsttx() const;
@@ -77,8 +77,11 @@ public:
   void setMode(const QString& tmode);
   QString getMode() const;  
 
-  void setPower(const QString& tpower);
-  QString getPower() const;  
+	void setPower(const QString& tpower);
+	QString getPower() const;
+
+	void setrxPower(const QString& tpower);
+	QString getrxPower() const;
 
   void setQslSenDateOn(const QDate tdate);
     QDate getQslSenDate() const;
@@ -137,9 +140,20 @@ public:
  void setPropMode(const QString &tprop_mode);
  QString getPropMode() const;
 
+/********************* CONTESTS ********************/
+	void setSrx (int tnumb);
+	int getSrx() const;
+	void setSrx_string(const QString &tsrx);
+	QString getSrx_string() const;
+	void setStx (int tnumb);
+	int getStx() const;
+	void setStx_string(const QString &tstx);
+	QString getStx_string() const;
+/********************* CONTESTS ********************/
   void clearQso();
 
 private:
+	QString	sAux;	//Auxiliar variable
   QString qrz;        // CALL
   int numb;           // STX
   QDateTime dateTime; // QSO_DATE/TIME_ON YYYYMMDD - Time HHMM (0000-2359)
@@ -170,6 +184,18 @@ private:
   QString name;       // NAME
   QString qth;        // QTH
   QString prop_mode;  // PROP_MODE QSO propagation mode
+/***************** CONTEST FIELDS *************************/
+	int srx;		//contest QSO received serial number
+	int stx;		//contest QSO transmitted serial number
+	QString srx_string; 	//contest QSO received information
+	QString stx_string; 	//contest QSO transmitted information
+/***************** CONTEST FIELDS *************************/
+	
+	// Checks that the data is not an ADIF field and replaces </> by a (/).
+	QString checkisNotAdif(const QString& tword);
+	QString checkLines(const QString& tword);
+
+
 	//int age;	//Contacted operator's age
 	//int ant_az;	//Antenna azimut in degrees
 	//int ant_el;	//Antena elevation
