@@ -190,6 +190,13 @@ void Setup::readConf(){
           }else if ((theData.upper() == "FALSE")){
             setupui::completeWithPreviouscheckBox->setChecked(false);
           }
+        }else if (adifTab == "REQUIREMANDATORY"){
+          if (theData.upper() == "TRUE"){
+            setupui::mandatoryDatacheckBox->setChecked(true);
+          }else if ((theData.upper() == "FALSE")){
+            setupui::mandatoryDatacheckBox->setChecked(false);
+          }
+
         }else if (adifTab == "TIMEUTC"){
           if (theData.upper() == "TRUE"){
             setupui::UTCcheckBox->setChecked(true);
@@ -364,15 +371,19 @@ void Setup::writeConf(){
 		}else{
 			tmp="false";
 		}
-		stream << "completewithprevious=" + tmp << endl;
+		stream << "dxclusterhfspots=" + tmp << endl;
 		if (setupui::completeWithPreviouscheckBox->isChecked()){
 			tmp="true";
 		}else{
 			tmp="false";
 		}
-
-    
-		stream << "dxclusterhfspots=" + tmp << endl;
+		stream << "completewithprevious=" + tmp << endl;
+		if (setupui::mandatoryDatacheckBox->isChecked()){
+			tmp="true";
+		}else{
+			tmp="false";
+		}
+		stream << "requiremandatory=" + tmp << endl;
 		if (setupui::VHFcheckBox->isChecked()){
 			tmp="true";
 		}else{
