@@ -370,11 +370,11 @@ int World::findEntity(const QString string){
       ij = prefixa.find("\\");
       if ( (abs)(ij) < (abs)(prefixa.length()-ij ) ) { //Like in F\EA4TV
         prefixab = prefixa.right(prefixa.length() - ij);
-        qrz2 = prefixab;        
+        qrz2 = prefixab;
       }else{// Like in F\EA4TV
         prefixab =  prefixa.left(ij-1);
-        qrz2 = prefixab;        
-      }      
+        qrz2 = prefixab;
+      }
     }
   }
   prefixa = prefixab;
@@ -489,9 +489,9 @@ Entity World::getEntByNumb(int num){
   }else{
       itN = nmap.begin();
   }
-  return (itN.data());  
-      
-/*  
+  return (itN.data());
+
+/*
  // found = false;
    for ( it = map.begin(); it != map.end(); ++it ) {
     if ( (it.data().getNumb()) == i){
@@ -500,7 +500,7 @@ Entity World::getEntByNumb(int num){
    }
     it = map.end();
     return (it.data());
-*/  
+*/
 }
 
 
@@ -562,22 +562,24 @@ int World::getItuz(){
 
   //EntityZMap cqMap, ituMap;
   //EntityNMap::Iterator itCQ, itITU;  
-  
-int World::getCqz(){  
+
+int World::getCqz(){
  // qrz = tpfx;
-    if (prefix=="NULL") // We are calling this function just after start KLog
- return 0;
-    
-  itCQ = cqMap.begin();
-  itCQ = cqMap.find(prefix);
-  if (cqMap.find(prefix) != cqMap.end()){
-      return itCQ.data();
-  }
-  else
-    return 0;        
+	if (prefix=="NULL") // We are calling this function just after start KLog
+		return 0;
+	itCQ = cqMap.begin();
+	itCQ = cqMap.find(prefix);
+	if (cqMap.find(prefix) != cqMap.end()){
+		return itCQ.data();
+	}
+	else
+		return 0;
 }
 
-
+int World::getCqzFromCall(const QString  tqrz){
+	i = findEntity(tqrz);
+	return getCqz();
+}
 
 int World::howManyEntities(){
   it = map.end();
@@ -585,4 +587,6 @@ int World::howManyEntities(){
 }
 
 bool World::isWorldCreated(){
-    return created;}
+    return created;
+}
+
