@@ -45,32 +45,33 @@ typedef QValueList<Entity> Entities;
 class World{
 public:
 
-  World();
-  
-  ~World();
-  
-  void create();
-  bool isWorldCreated();
+	World();
+
+	~World();
+
+	void create();
+	bool isWorldCreated();
+
+	int findEntity(const QString  string);	// If no Entity is found, we return "0"
 
-  int findEntity(const QString  string);	// If no Entity is found, we return "0"
-  
   // HACK: I should fool-proof this function adding a QString as a call to get the zone
-  QString getPrefix() const; // Returns the prefix we found in findEntity.
-  
-  //  int getEnti(const QString ttqrz);
+	QString getPrefix() const; // Returns the prefix we found in findEntity.
+
+//  int getEnti(const QString ttqrz);
 //  int getEntiCompleteQRZ(const QString ttqrz);
 //  Entity getEnt(const QString ttqrz);
-  Entity getEntByNumb(int num);
+	Entity getEntByNumb(int num);
 //  int getAdifNumber(const QString entity);
-  int giveEnt(const QString tqrz);
-  int howManyEntities();
-  
-  bool isSpecial(const QString &tpfx);  // This functions returns true if Entity has special zones
+	int giveEnt(const QString tqrz);
+	int howManyEntities();
+
+	bool isSpecial(const QString &tpfx);  // This functions returns true if Entity has special zones
                                         // per prefixes i.e. BY, UA, ...
-  int getItuz(); // HACK: I should fool-proof this function adding a QString as a call to get the zone
-  int getCqz();  // HACK: I should fool-proof this function adding a QString as a call to get the zone
+	int getItuz(); // HACK: I should fool-proof this function adding a QString as a call to get the zone
+	int getCqz();  // HACK: I should fool-proof this function adding a QString as a call to get the zone
 	//int getItuz(int tenti);
 	//int getCqz(int tenti);
+	int getCqzFromCall(const QString  tqrz); // Uses findEntity and getCqz
 // isSpecial,  maybe is to be deleted.
   
 private:
@@ -93,10 +94,10 @@ private:
 	typedef QMap<QString, int> EntityZMap;    // To map Prefix/Zone (CQ/ITU for all)
 //	typedef QMap<int, int> EntityIIMap;	// To map Zone/Entity(number)
 
-	EntityMap map; 
+	EntityMap map; 				// Prefix/Entity
 	EntityMap::Iterator it;
-	EntityNMap nmap;
-	EntityNMap::Iterator itN;
+	EntityNMap nmap;			// EntityNumber/Entity
+	EntityNMap::Iterator itN;		 
 	EntityZMap cqMap, ituMap;
 	EntityZMap::Iterator itCQ, itITU;
 //	EntityIIMap::cqMapi, ituMapi;			//TODO Map entity/zone to do things faster
